From: mchehab@brturbo.com.br
To: linux-kernel@vger.kernel.org
Cc: akpm@osdl.org, video4linux-list@redhat.com,
Ricardo Cerqueira <v4l@cerqueira.org>
Subject: [Patch 12/20] V4L(914) Use less generic name for saa7134 card 79
Date: Mon, 07 Nov 2005 00:58:09 -0200 [thread overview]
Message-ID: <1131333341.25215.25.camel@localhost> (raw)
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #1: Type: text/plain, Size: 2961 bytes --]
From: Ricardo Cerqueira <v4l@cerqueira.org>
- Use less-generic name for saa7134 card #79
Signed-off-by: Ricardo Cerqueira <v4l@cerqueira.org>
Signed-off-by: Mauro Carvalho Chehab <mchehab@brturbo.com.br>
-----------------
drivers/media/video/saa7134/saa7134-cards.c | 8 ++++----
drivers/media/video/saa7134/saa7134-input.c | 6 +++---
drivers/media/video/saa7134/saa7134.h | 2 +-
3 files changed, 8 insertions(+), 8 deletions(-)
--- hg.orig/drivers/media/video/saa7134/saa7134.h
+++ hg/drivers/media/video/saa7134/saa7134.h
@@ -205,7 +205,7 @@ struct saa7134_format {
#define SAA7134_BOARD_MONSTERTV_MOBILE 76
#define SAA7134_BOARD_PINNACLE_PCTV_110i 77
#define SAA7134_BOARD_ASUSTeK_P7131_DUAL 78
-#define SAA7134_BOARD_PCTV_CARDBUS 79
+#define SAA7134_BOARD_SEDNA_PC_TV_CARDBUS 79
#define SAA7134_BOARD_ASUSTEK_DIGIMATRIX_TV 80
#define SAA7134_BOARD_PHILIPS_TIGER 81
--- hg.orig/drivers/media/video/saa7134/saa7134-input.c
+++ hg/drivers/media/video/saa7134/saa7134-input.c
@@ -546,7 +546,7 @@ static IR_KEYTAB_TYPE ir_codes_pinnacle[
/* Mapping for the 28 key remote control as seen at
http://www.sednacomputer.com/photo/cardbus-tv.jpg
Pavel Mihaylov <bin@bash.info> */
-static IR_KEYTAB_TYPE pctv_cardbus_codes[IR_KEYTAB_SIZE] = {
+static IR_KEYTAB_TYPE pctv_sedna_codes[IR_KEYTAB_SIZE] = {
[ 0 ] = KEY_KP0,
[ 1 ] = KEY_KP1,
[ 2 ] = KEY_KP2,
@@ -781,8 +781,8 @@ int saa7134_input_init1(struct saa7134_d
mask_keyup = 0x004000;
polling = 50; // ms
break;
- case SAA7134_BOARD_PCTV_CARDBUS:
- ir_codes = pctv_cardbus_codes;
+ case SAA7134_BOARD_SEDNA_PC_TV_CARDBUS:
+ ir_codes = pctv_sedna_codes;
mask_keycode = 0x001f00;
mask_keyup = 0x004000;
polling = 50; // ms
_______________________________________________________
Yahoo! Acesso Grátis: Internet rápida e grátis.
Instale o discador agora!
http://br.acesso.yahoo.com/
reply other threads:[~2005-11-07 3:18 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1131333341.25215.25.camel@localhost \
--to=mchehab@brturbo.com.br \
--cc=akpm@osdl.org \
--cc=linux-kernel@vger.kernel.org \
--cc=v4l@cerqueira.org \
--cc=video4linux-list@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®
--- hg.orig/drivers/media/video/saa7134/saa7134-cards.c
+++ hg/drivers/media/video/saa7134/saa7134-cards.c
@@ -2452,11 +2452,11 @@ struct saa7134_board saa7134_boards[] =
.gpio = 0x0200000,
},
},
- [SAA7134_BOARD_PCTV_CARDBUS] = {
+ [SAA7134_BOARD_SEDNA_PC_TV_CARDBUS] = {
/* Paul Tom Zalac <pzalac@gmail.com> */
/* Pavel Mihaylov <bin@bash.info> */
- .name = "PCTV Cardbus TV/Radio (ITO25 Rev:2B)",
- /* Sedna Cardbus TV Tuner */
+ .name = "Sedna/MuchTV PC TV Cardbus TV/Radio (ITO25 Rev:2B)",
+ /* Sedna/MuchTV (OEM) Cardbus TV Tuner */
.audio_clock = 0x00187de7,
.tuner_type = TUNER_PHILIPS_TDA8290,
.radio_type = UNSET,
@@ -3067,7 +3067,7 @@ int saa7134_board_init1(struct saa7134_d
case SAA7134_BOARD_AVACSSMARTTV:
case SAA7134_BOARD_GOTVIEW_7135:
case SAA7134_BOARD_KWORLD_TERMINATOR:
- case SAA7134_BOARD_PCTV_CARDBUS:
+ case SAA7134_BOARD_SEDNA_PC_TV_CARDBUS:
dev->has_remote = SAA7134_REMOTE_GPIO;
break;
case SAA7134_BOARD_MD5044: